==> asksuite-core-1.0.72.tgz: package/package.util.js <==

require('datejs');
const API_AI_PARAMETER = "Subst_feriados";
let packageUtil = {};



packageUtil.findCurrentPackage = function(sessionContext, intent, companyId, functionFindPackage){

    return new Promise((resolve, reject) => {

        let sub = intent[API_AI_PARAMETER];

        if (sub && sub != "") {

            let dialog = companyId + "." + "pacotes";
            let findPaccote = functionFindPackage(dialog, sessionContext);

            console.log("Dialog"+dialog);
            console.log("Pacote Encontrado"+findPaccote);

            if (findPaccote) {

                let findCurrentPackage = findPaccote.value.find(item => {
                    return item.holiday == sub && packageUtil.isValidPackage(item);
                });



                if (findCurrentPackage) {
                    resolve(findCurrentPackage);
                }else{

                    let dialog = companyId + "." + "pacotes.naoexiste";
                    let packageDialogNotFound = functionFindPackage(dialog, sessionContext)

                    if (packageDialogNotFound) {
                        reject({type: 'package_not_found_exists', key: dialog + ".package", holiday: sub, package: packageDialogNotFound});
                    }else{
                       reject({type: 'package_not_found_not_exists'})
                    }
                }

            }else{
                reject({type: 'dialog_package_not_found'});
            }

        }else{
            reject({type: 'is_not_package'});
        }
    })

}


packageUtil.isValidPackage = function(packageAsk) {
    console.log("is active", packageAsk.active);
    return (Date.parse(packageAsk.dateEnd)  > new Date()) && packageAsk.active;
};






module.exports = packageUtil;

==> asksuite-core-1.0.79.tgz: package/package.util.js <==

require('datejs');
const API_AI_PARAMETER = "Subst_feriados";
let packageUtil = {};



packageUtil.findCurrentPackage = function(sessionContext, intent, companyId, functionFindPackage){

    return new Promise((resolve, reject) => {

        let sub = intent[API_AI_PARAMETER];

        if (sub && sub != "") {

            let dialog = companyId + "." + "pacotes";
            let findPaccote = functionFindPackage(dialog, sessionContext);

            console.log("Dialog"+dialog);
            console.log("Pacote Encontrado"+findPaccote);

            if (findPaccote) {


                let findCurrentPackage = findPaccote.value.filter(item => {
                    console.log(item.holiday + " "+sub);
                    console.log(packageUtil.isValidPackage(item));
                    return item.holiday == sub && packageUtil.isValidPackage(item);
                })[0]


                console.log("PACOTE"+findCurrentPackage)

                if (findCurrentPackage) {
                    resolve(findCurrentPackage);
                }else{

                    let dialog = companyId + "." + "pacotes.naoexiste";
                    let packageDialogNotFound = functionFindPackage(dialog, sessionContext)

                    if (packageDialogNotFound) {
                        reject({type: 'package_not_found_exists', key: dialog + ".package", holiday: sub, package: packageDialogNotFound});
                    }else{
                       reject({type: 'package_not_found_not_exists'})
                    }
                }

            }else{
                reject({type: 'dialog_package_not_found'});
            }

        }else{
            reject({type: 'is_not_package'});
        }
    })

}


packageUtil.isValidPackage = function(packageAsk) {
    console.log("#########################################################");
    console.log(packageAsk.dateEnd)
    console.log(Date.parse(packageAsk.dateEnd))
    console.log(Date.parse(packageAsk.dateEnd)  > new Date());
    console.log("#########################################################");
    return (Date.parse(packageAsk.dateEnd)  > new Date()) && packageAsk.active;
};






module.exports = packageUtil;
